<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="id" sourcelanguage="en">
<context>
    <name>Alert</name>
    <message>
        <source>Close (%1)</source>
        <translation>Tutup (%1)</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Tutup</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Buka</translation>
    </message>
</context>
<context>
    <name>AlertLayer</name>
    <message>
        <source>Dismiss Alert</source>
        <translation>Hilangkan Peringatan</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
</context>
<context>
    <name>DailyProgress</name>
    <message numerus="yes">
        <source>%Ln word(s)</source>
        <translation>
            <numerusform>%Ln kata</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>%Ln menit</numerusform>
        </translation>
    </message>
    <message>
        <source>0%</source>
        <translation>0%</translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln minute(s)</source>
        <translation>
            <numerusform>%L1% dari %Ln menit</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln word(s)</source>
        <translation>
            <numerusform>%L1% dari %Ln kata</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>DailyProgressDialog</name>
    <message>
        <source>Daily Progress</source>
        <translation>Kemajuan Harian</translation>
    </message>
    <message>
        <source>Longest streak</source>
        <translation>Rekor terpanjang</translation>
    </message>
    <message>
        <source>Current streak</source>
        <translation>Rekor saat ini</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation>
            <numerusform>%n hari</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 &amp;ndash; %2</source>
        <translation>%1 &amp;ndash; %2</translation>
    </message>
</context>
<context>
    <name>DailyProgressLabel</name>
    <message>
        <source>%L1% of daily goal</source>
        <translation>%L1% dari target harian</translation>
    </message>
</context>
<context>
    <name>DictionaryDialog</name>
    <message>
        <source>Set Language</source>
        <translation>Pilih Bahasa</translation>
    </message>
</context>
<context>
    <name>Document</name>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Tanpa Judul %1)</translation>
    </message>
    <message>
        <source>%1 (Read-Only)</source>
        <translation>%1 (Hanya Baca)</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Maaf</translation>
    </message>
    <message>
        <source>Unable to save &apos;%1&apos;.</source>
        <translation>Gagal menyimpan &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Save File As</source>
        <translation>Simpan File Sebagai</translation>
    </message>
    <message>
        <source>Unable to overwrite &apos;%1&apos;.</source>
        <translation>Gagal memperbarui &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Rename File</source>
        <translation>Ubah Nama File</translation>
    </message>
    <message>
        <source>Unable to rename &apos;%1&apos;.</source>
        <translation>Gagal mengubah nama &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Reload File?</source>
        <translation>Muat Ulang File</translation>
    </message>
    <message>
        <source>Reload the file &apos;%1&apos; from disk?</source>
        <translation>Muat ulang file %1 dari disk?</translation>
    </message>
    <message>
        <source>All unsaved changes will be lost.</source>
        <translation>Semua perubahan yang tidak disimpan akan hilang.</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Muat ulang</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Tanpa Judul %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pertanyaan</translation>
    </message>
    <message>
        <source>Saving as plain text will discard all formatting. Discard formatting?</source>
        <translation>Menyimpan sebagai teks polos akan membuang semua format. Buang format?</translation>
    </message>
</context>
<context>
    <name>DocumentWatcher</name>
    <message>
        <source>File Changed</source>
        <translation>File Berubah</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; was changed by another program.</source>
        <translation>File %1 berubah karena program lain.</translation>
    </message>
    <message>
        <source>Do you want to reload the file?</source>
        <translation>Apakah Anda ingin memuat file ini?</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Muat ulang</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Abaikan</translation>
    </message>
    <message>
        <source>File Deleted</source>
        <translation>File Dihapus</translation>
    </message>
    <message>
        <source>The file %1 was deleted by another program.</source>
        <translation>File %1 dihapus oleh program lain.</translation>
    </message>
    <message>
        <source>Do you want to save or close the file?</source>
        <translation>Apakah Anda ingin menyimpan atau menutup file ini?</translation>
    </message>
</context>
<context>
    <name>DocxReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Gagal membuka arsip.</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Search for:</source>
        <translation>Cari:</translation>
    </message>
    <message>
        <source>Replace with:</source>
        <translation>Gantikan dengan:</translation>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>Abaikan jenis huruf (kapital/kecil)</translation>
    </message>
    <message>
        <source>Whole words only</source>
        <translation>Hanya keseluruhan kata</translation>
    </message>
    <message>
        <source>Regular expressions</source>
        <translation>RegEx</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>Cari ke atas</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>Cari ke bawah</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Temukan...</translation>
    </message>
    <message>
        <source>&amp;Replace</source>
        <translation>&amp;Gantikan...</translation>
    </message>
    <message>
        <source>Replace &amp;All</source>
        <translation>Gantikan &amp;Semua</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Temukan</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Gantikan</translation>
    </message>
    <message numerus="yes">
        <source>Replace %n instance(s)?</source>
        <translation>
            <numerusform>Gantikan %n lainnya?</numerusform>
        </translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pertanyaan</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Maaf</translation>
    </message>
    <message>
        <source>Phrase not found.</source>
        <translation>Frase tidak ditemukan.</translation>
    </message>
</context>
<context>
    <name>FormatManager</name>
    <message>
        <source>OpenDocument Text</source>
        <translation>Teks OpenDocument</translation>
    </message>
    <message>
        <source>Office Open XML</source>
        <translation>Office Open XML</translation>
    </message>
    <message>
        <source>Rich Text Format</source>
        <translation>Rich Text Format</translation>
    </message>
    <message>
        <source>Plain Text</source>
        <translation>Teks Polos</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>Semua File</translation>
    </message>
    <message>
        <source>All Supported Files</source>
        <translation>Semua File Yang Didukung</translation>
    </message>
    <message>
        <source>OpenDocument Flat XML</source>
        <translation>Buka berkas XML</translation>
    </message>
</context>
<context>
    <name>Highlighter</name>
    <message>
        <source>Add</source>
        <translation>Tambahkan</translation>
    </message>
    <message>
        <source>Check Spelling...</source>
        <translation>Cek Ejaan...</translation>
    </message>
    <message>
        <source>(No suggestions found)</source>
        <translation>(Saran tidak ditemukan)</translation>
    </message>
</context>
<context>
    <name>ImageButton</name>
    <message>
        <source>Open Image</source>
        <translation>Buka Gambar</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Gambar</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Pilih bahasa:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;System Language&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Catatan</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Silakan tutup dan buka kembali aplikasi ini untuk menerapkan perubahan bahasa.</translation>
    </message>
</context>
<context>
    <name>OdtReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Gagal membuka arsip.</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Preferensi</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Umum</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statistik</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Bilah Peralatan</translation>
    </message>
    <message>
        <source>Spell Checking</source>
        <translation>Pemeriksaan Ejaan</translation>
    </message>
    <message>
        <source>Select Dictionary</source>
        <translation>Pilih Kamus</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Maaf</translation>
    </message>
    <message>
        <source>Unable to open archive.</source>
        <translation>Gagal membuka arsip.</translation>
    </message>
    <message>
        <source>The archive does not contain a usable dictionary.</source>
        <translation>Arsip ini tidak memiliki kamus yang bisa dipergunakan.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pertanyaan</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Shortcuts</translation>
    </message>
    <message>
        <source>One or more shortcuts conflict. Do you wish to proceed?</source>
        <translation>Satu atau lebih shortcuts beradu. Apakah Anda ingin melanjutkan?</translation>
    </message>
    <message>
        <source>The dictionary &quot;%1&quot; already exists. Do you want to replace it?</source>
        <translation>Kamus &quot;%1&quot; sudah ada. Anda ingin menggantikannya?</translation>
    </message>
    <message>
        <source>Daily Goal</source>
        <translation>Target Harian</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Tak satupun</translation>
    </message>
    <message>
        <source>Minutes:</source>
        <translation>Menit:</translation>
    </message>
    <message>
        <source>Words:</source>
        <translation>Kata:</translation>
    </message>
    <message>
        <source>Editing</source>
        <translation>Mengedit</translation>
    </message>
    <message>
        <source>Always vertically center</source>
        <translation>Selalu tengah secara vertikal</translation>
    </message>
    <message>
        <source>Block insertion cursor</source>
        <translation>Blok kursor sisipan</translation>
    </message>
    <message>
        <source>Smooth fonts</source>
        <translation>Font halus</translation>
    </message>
    <message>
        <source>Typewriter sounds</source>
        <translation>Suara Mesin Ketik</translation>
    </message>
    <message>
        <source>Smart quotes:</source>
        <translation>Kutipan cerdas:</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Ganda</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Tunggal</translation>
    </message>
    <message>
        <source>Scenes</source>
        <translation>Suasana</translation>
    </message>
    <message>
        <source>Divider:</source>
        <translation>Pembagi:</translation>
    </message>
    <message>
        <source>Saving</source>
        <translation>Menyimpan</translation>
    </message>
    <message>
        <source>Remember cursor position</source>
        <translation>Ingat posisi kursor</translation>
    </message>
    <message>
        <source>Word count</source>
        <translation>Jumlah kata</translation>
    </message>
    <message>
        <source>Page count</source>
        <translation>Jumlah halaman</translation>
    </message>
    <message>
        <source>Paragraph count</source>
        <translation>Jumlah paragraf</translation>
    </message>
    <message>
        <source>Character count</source>
        <translation>Jumlah karakter</translation>
    </message>
    <message>
        <source>Characters:</source>
        <translation>Karakter:</translation>
    </message>
    <message>
        <source>Paragraphs:</source>
        <translation>Paragraf:</translation>
    </message>
    <message>
        <source>Word Count Algorithm</source>
        <translation>Algoritma Penjumlahan Kata</translation>
    </message>
    <message>
        <source>Reset daily progress for today to zero?</source>
        <translation>Reset kemajuan harian hari ini ke nol?</translation>
    </message>
    <message>
        <source>Write byte order mark in plain text files</source>
        <translation>Tulis byte order mark di file teks polos</translation>
    </message>
    <message>
        <source>Default format:</source>
        <translation>Format standar:</translation>
    </message>
    <message>
        <source>Reset Today</source>
        <translation>Reset Hari Ini</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Riwayat</translation>
    </message>
    <message>
        <source>Remember history</source>
        <translation>Ingat riwayat</translation>
    </message>
    <message>
        <source>Show streaks</source>
        <translation>Tampilkan rekor</translation>
    </message>
    <message>
        <source>Minimum progress for streaks:</source>
        <translation>Kemajuan minimum untuk rekor:</translation>
    </message>
    <message>
        <source>Detect word boundaries</source>
        <translation>Deteksi batas-batas kata</translation>
    </message>
    <message>
        <source>Divide character count by six</source>
        <translation>Bagikan jumlah karakter dengan 6</translation>
    </message>
    <message>
        <source>Count each letter as a word</source>
        <translation>Hitung tiap huruf sebagai kata</translation>
    </message>
    <message>
        <source>Page Count Algorithm</source>
        <translation>Algoritma Penghitungan Halaman</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Gaya</translation>
    </message>
    <message>
        <source>Icons Only</source>
        <translation>Ikon saja</translation>
    </message>
    <message>
        <source>Text Only</source>
        <translation>Teks saja</translation>
    </message>
    <message>
        <source>Text Alongside Icons</source>
        <translation>Teks dan Ikon</translation>
    </message>
    <message>
        <source>Text Under Icons</source>
        <translation>Teks di bawah Ikon</translation>
    </message>
    <message>
        <source>Text Position:</source>
        <translation>Posisi Teks:</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Tindakan:</translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation>Naik</translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation>Turun</translation>
    </message>
    <message>
        <source>Add Separator</source>
        <translation>Tambahkan Pemisah</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Perintah</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Shortcut</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Tindakan</translation>
    </message>
    <message>
        <source>Check spelling as you type</source>
        <translation>Cek ejaan saat Anda mengetik</translation>
    </message>
    <message>
        <source>Ignore words in UPPERCASE</source>
        <translation>Abaikan kata dalam huruf KAPITAL</translation>
    </message>
    <message>
        <source>Ignore words with numbers</source>
        <translation>Abaikan kata dengan angka</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Bahasa</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Tambahkan</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Hapus</translation>
    </message>
    <message>
        <source>Personal Dictionary</source>
        <translation>Kamus Pribadi</translation>
    </message>
    <message>
        <source>Remove current dictionary?</source>
        <translation>Hilangkan kamus ini?</translation>
    </message>
    <message>
        <source>User Interface</source>
        <translation>Tampilan pengguna</translation>
    </message>
    <message>
        <source>Always show scrollbar</source>
        <translation>Scrollbar selalu tampak</translation>
    </message>
    <message>
        <source>Always show top bar</source>
        <translation>Bilah atas selalu tampak</translation>
    </message>
    <message>
        <source>Always show bottom bar</source>
        <translation>Bilah bawah selalu tampak</translation>
    </message>
</context>
<context>
    <name>RtfReader</name>
    <message>
        <source>Not a supported RTF file.</source>
        <translation>Bukan file RTF yang didukung.</translation>
    </message>
</context>
<context>
    <name>RtfTokenizer</name>
    <message>
        <source>Unexpectedly reached end of file.</source>
        <translation>Mencapai akhir file tanpa diduga.</translation>
    </message>
</context>
<context>
    <name>SceneList</name>
    <message>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+Down</translation>
    </message>
    <message>
        <source>Move Scenes Up</source>
        <translation>Naikkan Suasana</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+Up</translation>
    </message>
    <message>
        <source>Toggle Scene List</source>
        <translation>Toggle List Suasana</translation>
    </message>
    <message>
        <source>Shift+F4</source>
        <translation>Shift+F4</translation>
    </message>
    <message>
        <source>Show scene list (%1)</source>
        <translation>Tampilkan list suasana (%1)</translation>
    </message>
    <message>
        <source>Hide scene list (%1)</source>
        <translation>Sembunyian list suasana (%1)</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filter</translation>
    </message>
    <message>
        <source>Move Scenes Down</source>
        <translation>Turunkan Suasana</translation>
    </message>
    <message>
        <source>Resize scene list</source>
        <translation>Ubah ukuran list suasana</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <source>Default</source>
        <translation>Setelan Standar</translation>
    </message>
</context>
<context>
    <name>SessionManager</name>
    <message>
        <source>Manage Sessions</source>
        <translation>Kelola Sesi</translation>
    </message>
    <message>
        <source>S&amp;essions</source>
        <translation>S&amp;esi</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Baru</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplikat</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Ubah Nama</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Hapus</translation>
    </message>
    <message>
        <source>Switch To</source>
        <translation>Pindah Ke</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Sesi Baru</translation>
    </message>
    <message>
        <source>Duplicate Session</source>
        <translation>Duplikat Sesi</translation>
    </message>
    <message>
        <source>Rename Session</source>
        <translation>Ubah Nama Sesi</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pertanyaan</translation>
    </message>
    <message>
        <source>Delete selected session?</source>
        <translation>Hapus sesi terpilih?</translation>
    </message>
    <message>
        <source>Session name:</source>
        <translation>Judul sesi:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Maaf</translation>
    </message>
    <message>
        <source>The requested session name is already in use.</source>
        <translation>Nama sesi sudah pernah dipakai.</translation>
    </message>
    <message>
        <source>&amp;New...</source>
        <translation>&amp;Baru...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;Manage...</source>
        <translation>&amp;Kelola...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+M</source>
        <translation>Ctrl+Shift+M</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <source>Clear</source>
        <translation>Bersihkan</translation>
    </message>
    <message>
        <source>Reset to Default</source>
        <translation>Setelan Standar</translation>
    </message>
    <message>
        <source>Shortcut:</source>
        <translation>Shortcut:</translation>
    </message>
</context>
<context>
    <name>SmartQuote</name>
    <message>
        <source>Replacing quotation marks...</source>
        <translation>Mengganti tanda kutip...</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Mohon Tunggu</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Check Spelling</source>
        <translation>Memeriksa Ejaan</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Tambahkan</translation>
    </message>
    <message>
        <source>&amp;Ignore</source>
        <translation>&amp;Abaikan</translation>
    </message>
    <message>
        <source>I&amp;gnore All</source>
        <translation>Abaikan &amp;Semua</translation>
    </message>
    <message>
        <source>&amp;Change</source>
        <translation>&amp;Ubah</translation>
    </message>
    <message>
        <source>C&amp;hange All</source>
        <translation>U&amp;bah Semua</translation>
    </message>
    <message>
        <source>Not in dictionary:</source>
        <translation>Tak ada dalam kamus:</translation>
    </message>
    <message>
        <source>Change to:</source>
        <translation>Ubah menjadi:</translation>
    </message>
    <message>
        <source>Checking spelling...</source>
        <translation>Memeriksa ejaan...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Batalkan</translation>
    </message>
    <message>
        <source>Please wait</source>
        <translation>Silakan tunggu</translation>
    </message>
    <message>
        <source>Continue checking at beginning of file?</source>
        <translation>Lanjutkan mengecek awal file?</translation>
    </message>
    <message>
        <source>Spell check complete.</source>
        <translation>Ejaan selesai diperiksa.</translation>
    </message>
</context>
<context>
    <name>SymbolsDialog</name>
    <message>
        <source>Symbols</source>
        <translation>Simbol</translation>
    </message>
    <message>
        <source>Recently used symbols</source>
        <translation>Simbol baru dipakai</translation>
    </message>
    <message>
        <source>All symbols</source>
        <translation>Semua simbol</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Rincian</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nama:</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Sisipkan</translation>
    </message>
</context>
<context>
    <name>SymbolsModel</name>
    <message>
        <source>Blocks</source>
        <translation>Blok</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>Naskah</translation>
    </message>
</context>
<context>
    <name>Theme</name>
    <message>
        <source>Untitled %1</source>
        <translation>Tanpa Judul %1</translation>
    </message>
</context>
<context>
    <name>ThemeDialog</name>
    <message>
        <source>Name:</source>
        <translation>Nama:</translation>
    </message>
    <message>
        <source>No Image</source>
        <translation>Tanpa gambar</translation>
    </message>
    <message>
        <source>Tiled</source>
        <translation>Berjajar</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation>Terpusat</translation>
    </message>
    <message>
        <source>Stretched</source>
        <translation>Terhampar</translation>
    </message>
    <message>
        <source>Scaled</source>
        <translation>Terskala</translation>
    </message>
    <message>
        <source>Zoomed</source>
        <translation>Di-zoom</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>Transparansi:</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation>Posisi:</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Lebar:</translation>
    </message>
    <message>
        <source>Round Text Background Corners</source>
        <translation>Sudut Latar Teks Bulat</translation>
    </message>
    <message>
        <source>Radius:</source>
        <translation>Radius:</translation>
    </message>
    <message>
        <source>Blur Text Background</source>
        <translation>Latar Teks Blur</translation>
    </message>
    <message>
        <source>Text Background Drop Shadow</source>
        <translation>Bayangan Latar Teks</translation>
    </message>
    <message>
        <source>Vertical Offset:</source>
        <translation>Offset Vertikal:</translation>
    </message>
    <message>
        <source>Margins</source>
        <translation>Marjin</translation>
    </message>
    <message>
        <source>Window:</source>
        <translation>Jendela:</translation>
    </message>
    <message>
        <source>Page:</source>
        <translation>Halaman:</translation>
    </message>
    <message>
        <source>Indent first line</source>
        <translation>Indent baris pertama</translation>
    </message>
    <message>
        <source>Above:</source>
        <translation>Di Atas: </translation>
    </message>
    <message>
        <source>Below:</source>
        <translation>Di Bawah:</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Buang</translation>
    </message>
    <message>
        <source>Edit Theme</source>
        <translation>Edit Tema</translation>
    </message>
    <message>
        <source>Window Background</source>
        <translation>Latar Jendela</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipe:</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Warna:</translation>
    </message>
    <message>
        <source>Image:</source>
        <translation>Gambar:</translation>
    </message>
    <message>
        <source> pixels</source>
        <translation>piksel</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Kiri</translation>
    </message>
    <message>
        <source>Text Background</source>
        <translation>Latar Teks</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Kanan</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Teks</translation>
    </message>
    <message>
        <source>Font:</source>
        <translation>Font:</translation>
    </message>
    <message>
        <source>Misspelled:</source>
        <translation>Keliru eja:</translation>
    </message>
    <message>
        <source>Line Spacing</source>
        <translation>Jarak Baris</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Tunggal</translation>
    </message>
    <message>
        <source>1.5 Lines</source>
        <translation>1.5 Baris</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Ganda</translation>
    </message>
    <message>
        <source>Proportional</source>
        <translation>Proporsional</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Tinggi:</translation>
    </message>
    <message>
        <source>Paragraph Spacing</source>
        <translation>Jarak Paragraf</translation>
    </message>
    <message>
        <source>Tab Width:</source>
        <translation>Lebar Tab:</translation>
    </message>
    <message>
        <source>New Theme</source>
        <translation>Tema Baru</translation>
    </message>
</context>
<context>
    <name>ThemeManager</name>
    <message>
        <source>Themes</source>
        <translation>Tema</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Standar</translation>
    </message>
    <message>
        <source>Gentle Blues</source>
        <translation>Gentle Blues</translation>
    </message>
    <message>
        <source>Old School</source>
        <translation>Old School</translation>
    </message>
    <message>
        <source>Space Dreams</source>
        <translation>Space Dreams</translation>
    </message>
    <message>
        <source>Writing Desk</source>
        <translation>Nulis Meja</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Baru</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplikat</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Buatan</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Edit</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Hapus</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Impor</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Ekspor</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pertanyaan</translation>
    </message>
    <message>
        <source>Delete theme &apos;%1&apos;?</source>
        <translation>Hapus tema &apos;%1&apos;?</translation>
    </message>
    <message>
        <source>Themes (%1)</source>
        <translation>Tema (%1)</translation>
    </message>
    <message>
        <source>Import Theme</source>
        <translation>Impor Tema</translation>
    </message>
    <message>
        <source>Export Theme</source>
        <translation>Ekspor Tema</translation>
    </message>
    <message>
        <source>Bitter Skies</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enchantment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Spy Games</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tranquility</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Timer</name>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; - %2</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; - %2</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pertanyaan</translation>
    </message>
    <message>
        <source>Delete timer?</source>
        <translation>Hapus pengukur waktu?</translation>
    </message>
    <message>
        <source>&lt;b&gt;Words:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Kata:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pages:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Halaman:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Paragraphs:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Paragraf:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Characters:&lt;/b&gt; %L1 / %L2</source>
        <translation>&lt;b&gt;Karakter:&lt;/b&gt; %L1 / %L2</translation>
    </message>
    <message>
        <source>Set Delay</source>
        <translation>Atur Penundaan</translation>
    </message>
    <message>
        <source>Set Time</source>
        <translation>Atur Waktu</translation>
    </message>
    <message>
        <source>Delay:</source>
        <translation>Tunda:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Waktu:</translation>
    </message>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>Alarm</source>
        <translation>Alarm</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Jenis:</translation>
    </message>
    <message>
        <source>Memo:</source>
        <translation>Memo:</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Edit</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Hapus</translation>
    </message>
</context>
<context>
    <name>TimerDisplay</name>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>No timers running</source>
        <translation>Tak ada pengukur waktu yang dijalankan</translation>
    </message>
</context>
<context>
    <name>TimerManager</name>
    <message>
        <source>Timers</source>
        <translation>Pengukur Waktu</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Baru</translation>
    </message>
    <message>
        <source>Recent</source>
        <translation>Mutakhir</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pertanyaan</translation>
    </message>
    <message>
        <source>Cancel editing timers?</source>
        <translation>Batalkan pengaturan waktu?</translation>
    </message>
    <message>
        <source>+HH:mm:ss</source>
        <translation>+HH:mm:ss</translation>
    </message>
    <message>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Loading themes</source>
        <translation>Memuat tema</translation>
    </message>
    <message>
        <source>Loading sounds</source>
        <translation>Memuat suara</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Tanpa Judul</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Buka File</translation>
    </message>
    <message>
        <source>About FocusWriter</source>
        <translation>Tentang FocusWriter</translation>
    </message>
    <message>
        <source>FocusWriter</source>
        <translation>FocusWriter</translation>
    </message>
    <message>
        <source>A simple fullscreen word processor</source>
        <translation>Pengolah kata selayar penuh sederhana</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Hak Cipta &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Dirilis dalam lisensi &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>Menggunakan ikon dari tema ikon &lt;a href=%1&gt;Oxygen&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Digunakan dalam lisensi &lt;a href=%1&gt;LGPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Characters: %L1 / %L2</source>
        <translation>Karakter: %L1 / %L2</translation>
    </message>
    <message>
        <source>Pages: %L1</source>
        <translation>Halaman: %L1</translation>
    </message>
    <message>
        <source>Paragraphs: %L1</source>
        <translation>Paragraf: %L1</translation>
    </message>
    <message>
        <source>Words: %L1</source>
        <translation>Kata: %L1</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Membuka %1</translation>
    </message>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Tanpa Judul %1)</translation>
    </message>
    <message>
        <source>List all documents</source>
        <translation>List semua dokumen</translation>
    </message>
    <message>
        <source>Switch to Next Document</source>
        <translation>Beralih Ke Dokumen Berikutnya</translation>
    </message>
    <message>
        <source>Switch to Previous Document</source>
        <translation>Beralih Ke Dokumen Sebelumnya</translation>
    </message>
    <message>
        <source>Switch to First Document</source>
        <translation>Beralih Ke Dokumen Pertama</translation>
    </message>
    <message>
        <source>Switch to Last Document</source>
        <translation>Beralih Ke Dokumen Terakhir</translation>
    </message>
    <message>
        <source>Switch to Document %1</source>
        <translation>Beralih Ke Dokumen %1</translation>
    </message>
    <message>
        <source>Loading settings</source>
        <translation>Memuat pengaturan</translation>
    </message>
    <message>
        <source>Emergency cache is not writable.</source>
        <translation>Penyimpanan darurat tak bisa diedit.</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Peringatan</translation>
    </message>
    <message>
        <source>FocusWriter was not shut down cleanly.</source>
        <translation>FocusWriter tidak ditutup dengan baik.</translation>
    </message>
    <message>
        <source>Restore from the emergency cache?</source>
        <translation>Kembalikan dari penyimpanan darurat?</translation>
    </message>
    <message>
        <source>Some files could not be opened.</source>
        <translation>Beberapa file tak bisa dibuka.</translation>
    </message>
    <message>
        <source>Some files were opened Read-Only.</source>
        <translation>Beberapa file dibuka secara Read-Only (tak bisa diedit).</translation>
    </message>
    <message>
        <source>&apos;%1&apos; is newer than the cached copy.</source>
        <translation>&apos;%1&apos; lebih mutakhir daripada kopian yang tersimpan.</translation>
    </message>
    <message>
        <source>Overwrite newer file?</source>
        <translation>Timpa file yang lebih baru?</translation>
    </message>
    <message>
        <source>Save Changes?</source>
        <translation>Simpan Perubahan?</translation>
    </message>
    <message>
        <source>Save changes to the file &apos;%1&apos; before closing?</source>
        <translation>Simpan perubahan ke file &apos;%1&apos; sebelum keluar?</translation>
    </message>
    <message>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>Perubahan Anda akan hilang jika Anda tidak menyimpan mereka.</translation>
    </message>
    <message>
        <source>Unable to load typewriter sounds.</source>
        <translation>Gagal memuat suara mesin ketik.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;File</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Baru</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;Buka...</translation>
    </message>
    <message>
        <source>Reloa&amp;d</source>
        <translation>&amp;Muat Ulang</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Simpan</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>Simpan &amp;sebagai...</translation>
    </message>
    <message>
        <source>&amp;Rename...</source>
        <translation>&amp;Ubah Nama...</translation>
    </message>
    <message>
        <source>Save A&amp;ll</source>
        <translation>Simpan S&amp;emua</translation>
    </message>
    <message>
        <source>Manage Sessions</source>
        <translation>Kelola Sesi</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Sesi Baru</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>&amp;Cetak...</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Tutup</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Keluar</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Edit</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Undo</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Redo</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>Po%tong</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Salin</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>&amp;Tempelkan</translation>
    </message>
    <message>
        <source>Paste &amp;Unformatted</source>
        <translation>Paste &amp;Tanpa Format</translation>
    </message>
    <message>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl+Shift+V</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>Pilih &amp;Semua</translation>
    </message>
    <message>
        <source>Select &amp;Scene</source>
        <translation>Pilih &amp;Suasana</translation>
    </message>
    <message>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <source>Fo&amp;rmat</source>
        <translation>Fo&amp;rmat</translation>
    </message>
    <message>
        <source>&amp;Bold</source>
        <translation>&amp;Tebal</translation>
    </message>
    <message>
        <source>&amp;Italic</source>
        <translation>&amp;Miring</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>&amp;Garisbawah</translation>
    </message>
    <message>
        <source>Stri&amp;kethrough</source>
        <translation>Gar&amp;iscoret</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Sup&amp;erscript</source>
        <translation>Sup&amp;erscript</translation>
    </message>
    <message>
        <source>Ctrl+^</source>
        <translation>Ctrl+^</translation>
    </message>
    <message>
        <source>&amp;Subscript</source>
        <translation>&amp;Subscript</translation>
    </message>
    <message>
        <source>Ctrl+_</source>
        <translation>Ctrl+_</translation>
    </message>
    <message>
        <source>Align &amp;Left</source>
        <translation>Rata &amp;Kiri</translation>
    </message>
    <message>
        <source>Ctrl+{</source>
        <translation>Ctrl+{</translation>
    </message>
    <message>
        <source>Align &amp;Center</source>
        <translation>Rata &amp;Tengah</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <source>Align &amp;Right</source>
        <translation>Rata &amp;Kanan</translation>
    </message>
    <message>
        <source>Ctrl+}</source>
        <translation>Ctrl+}</translation>
    </message>
    <message>
        <source>Align &amp;Justify</source>
        <translation>Rata &amp;Sisi</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>&amp;Decrease Indent</source>
        <translation>%Kurangi Indentasi</translation>
    </message>
    <message>
        <source>Ctrl+&lt;</source>
        <translation>Ctrl+&lt;</translation>
    </message>
    <message>
        <source>I&amp;ncrease Indent</source>
        <translation>T&amp;ambahkan Indentasi</translation>
    </message>
    <message>
        <source>Ctrl+&gt;</source>
        <translation>Ctrl+&gt;</translation>
    </message>
    <message>
        <source>Le&amp;ft to Right Block</source>
        <translation>Bl&amp;ok Kiri ke Kanan</translation>
    </message>
    <message>
        <source>Ri&amp;ght to Left Block</source>
        <translation>Bl&amp;ok Kanan ke Kiri</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Peralatan</translation>
    </message>
    <message>
        <source>&amp;Find...</source>
        <translation>&amp;Temukan...</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>Temukan &amp;berikutnya</translation>
    </message>
    <message>
        <source>Find Pre&amp;vious</source>
        <translation>Temukan Seb&amp;elumnya</translation>
    </message>
    <message>
        <source>&amp;Replace...</source>
        <translation>&amp;Gantikan...</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Smart &amp;Quotes</source>
        <translation>Kutipan &amp;Cerdas</translation>
    </message>
    <message>
        <source>Update &amp;Document</source>
        <translation>Perbarui &amp;Dokumen</translation>
    </message>
    <message>
        <source>Update &amp;Selection</source>
        <translation>Perbarui &amp;Seleksi</translation>
    </message>
    <message>
        <source>&amp;Spelling...</source>
        <translation>%Ejaan...</translation>
    </message>
    <message>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <source>Set &amp;Language...</source>
        <translation>Pilih &amp;Bahasa...</translation>
    </message>
    <message>
        <source>&amp;Timers...</source>
        <translation>&amp;Pengatur Waktu...</translation>
    </message>
    <message>
        <source>S&amp;ymbols...</source>
        <translation>S&amp;imbol...</translation>
    </message>
    <message>
        <source>&amp;Daily Progress</source>
        <translation>&amp;Kemajuan Harian</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Pengaturan</translation>
    </message>
    <message>
        <source>Show &amp;Toolbar</source>
        <translation>Tampilkan &amp;Bilah Alat</translation>
    </message>
    <message>
        <source>Show &amp;Menu Icons</source>
        <translation>Tampilkan &amp;Ikon Menu</translation>
    </message>
    <message>
        <source>F&amp;ocused Text</source>
        <translation>Teks Yang Difokus</translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Layar Penuh</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <source>M&amp;inimize</source>
        <translation>M&amp;inimize</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Themes...</source>
        <translation>&amp;Tema...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Preferensi...</translation>
    </message>
    <message>
        <source>Focus Off</source>
        <translation>Fokus Mati</translation>
    </message>
    <message>
        <source>Focus One Line</source>
        <translation>Fokus Satu Baris</translation>
    </message>
    <message>
        <source>Focus Three Lines</source>
        <translation>Fokus Tiga Baris</translation>
    </message>
    <message>
        <source>&amp;Paragraph</source>
        <translation>&amp;Paragraf</translation>
    </message>
    <message>
        <source>Focus Paragraph</source>
        <translation>Fokus Paragraf</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Bantuan</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Bahasa &amp;Aplikasi...</translation>
    </message>
    <message>
        <source>Some files were unsupported and could not be opened.</source>
        <translation>Beberapa file tak didukung dan tak bisa dibuka.</translation>
    </message>
    <message>
        <source>&amp;Off</source>
        <translation>&amp;Mati</translation>
    </message>
    <message>
        <source>One &amp;Line</source>
        <translation>Satu &amp;Baris</translation>
    </message>
    <message>
        <source>&amp;Three Lines</source>
        <translation>&amp;Tiga Baris</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Tentang</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Tentang &amp;Qt</translation>
    </message>
    <message>
        <source>Pa&amp;ge Setup...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Heading</source>
        <translation>&amp;Heading</translation>
    </message>
    <message>
        <source>Heading &amp;1</source>
        <translation>Heading &amp;1</translation>
    </message>
    <message>
        <source>Heading &amp;2</source>
        <translation>Heading &amp;2</translation>
    </message>
    <message>
        <source>Heading &amp;3</source>
        <translation>Heading &amp;3</translation>
    </message>
    <message>
        <source>Heading &amp;4</source>
        <translation>Heading &amp;4</translation>
    </message>
    <message>
        <source>Heading &amp;5</source>
        <translation>Heading &amp;5</translation>
    </message>
    <message>
        <source>Heading &amp;6</source>
        <translation>Heading &amp;6</translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation>&amp;Normal</translation>
    </message>
    <message>
        <source>Update Document Smart Quotes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update Selection Smart Quotes</source>
        <translation>Perbarui Pilhan Kutipan Cerdas</translation>
    </message>
    <message>
        <source>Ctrl+Shift+`</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Files to open in current session.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
